;; Generated package description from hyperbole.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "hyperbole" "9.1.0.0.20260830.48" "GNU Hyperbole: The Everyday Hypertextual Information Manager" '((emacs "28")) :commit "5670b645ce1a5b46656b1401c4db83e787ea9513" :authors '(("Robert Weiner" . "rsw@gnu.org")) :maintainer '(("Robert Weiner" . "rsw@gnu.org") ("Mats Lidell" . "matsl@gnu.org")) :keywords '("comm" "convenience" "files" "frames" "hypermedia" "languages" "mail" "matching" "mouse" "multimedia" "outlines" "tools" "wp") :url "http://www.gnu.org/software/hyperbole")
