/*
   Custom CSS for HTML documents generated with Texinfo 7.x's makeinfo.
   Public domain 2023 Luis Felipe López Acevedo. All rights waived.
*/


/* VARIABLES */
:root {
    color-scheme: light dark;
    /* Colors */
    --bg-color: #F0F0F0;
    --border-color: silver;
    --link-color: #245C8A;
    --sheet-color: white;
    --sheet-shadow: gray;
    --symbol-color: saddlebrown;
    --text-color: #333;
    /* Fonts */
    --base-font-size: 16px;
}

@media (prefers-color-scheme: dark) {
    :root {
        --bg-color: #191919;
        --border-color: black;
        --link-color: #8EB2CD;
        --sheet-color: #222;
        --sheet-shadow: var(--border-color);
        --symbol-color: darkkhaki;
        --text-color: #F5F5F5;
    }
}
/* END VARIABLES */



/* NATIVE ELEMENTS */
a:link,
a:visited {
    color: var(--link-color);
    text-decoration: none;
}

a:active,
a:focus,
a:hover {
    text-decoration: underline;
}

abbr,
acronym {
    cursor: help;
}

blockquote {
    border-color: var(--text-color);
    border-style: none none none solid;
    border-width: 0.5em;
    margin-left: 0em;
    padding-left: 1.5em;
}

body {
    background-color: var(--sheet-color);
    box-shadow: 0 0 2px var(--sheet-shadow);
    box-sizing: border-box;
    color: var(--text-color);
    font-family: sans-serif;
    font-size: var(--base-font-size);
    margin: 50px auto;
    max-width: 960px;
    padding: 50px;
}

code,
samp,
tt,
var {
    color: var(--symbol-color);
}

div.example,
div.lisp {
    margin: 0px;
}

dl {
    margin: 3em 0em;
}

dl dl {
    margin: 0em;
}

dt {
    background-color: var(--bg-color);
    padding: 0.5em;
}

dd dt {
    background-color: transparent;
    border-color: var(--border-color);
    border-style: none none none dotted;
    border-width: 0.5em;
    padding: 0.5em;
}

h1,
h2,
h2.contents-heading,
h3,
h4 {
    padding: 20px 0px 0px 0px;
    font-weight: normal;
}

h1 {
    font-size: 2.4em;
}

h2 {
    font-size: 2.2em;
    font-weight: bold;
}

h3 {
    font-size: 1.8em;
}

h4 {
    font-size: 1.4em;
}

hr {
    background-color: var(--border-color);
    border-style: none;
    height: 1px;
    margin: 0px;
}

html {
    background-color: var(--bg-color);
}

img {
    max-width: 100%;
}

li {
    padding: 5px;
}

pre.display,
pre.example-preformatted,
pre.format,
pre.lisp-preformatted,
pre.verbatim{
    overflow: auto;
}

pre.example-preformatted,
pre.lisp-preformatted,
pre.verbatim {
    background-color: #2D3743;
    border-color: black;
    border-style: solid;
    border-width: thin;
    color: #E1E1E1;
    font-size: smaller;
    padding: 1em;
}

pre.menu-comment-preformatted {
    border-color: var(--bg-color);
    border-bottom-style: solid;
    border-width: thin;
    font-family: sans;
}

strong.def-name {
    font-size: var(--base-font-size);
}

table {
    border-collapse: collapse;
    margin: 40px 0px;
}

table.cp-entries-printindex *,
table.fn-entries-printindex *,
table.ky-entries-printindex *,
table.pg-entries-printindex *,
table.tp-entries-printindex *,
table.vr-entries-printindex * {
    background-color: inherit;
    border-style: none;
}

td,
th {
    border-color: var(--border-color);
    border-style: solid;
    border-width: thin;
    padding: 10px;
}

th {
    background-color: var(--bg-color);
}
/* END NATIVE ELEMENTS */



/* CLASSES */
.contents {
    margin-bottom: 4em;
}

.def-type {
    color: var(--text-color);
}

.def-var-arguments {
    color: var(--text-color);
}

.float {
    margin: 3em 0em;
}

.caption {
    font-size: smaller;
    text-align: center;
}

.float > img {
    display: block;
    margin: auto;
}

.footnote {
    font-size: smaller;
    margin: 5em 0em;
}

.footnote h3 {
    display: inline;
    font-size: small;
}

.key {
    color: var(--symbol-color);
}

.menu * {
    border-style: none;
}

.menu td {
    padding: 0.5em 0em;
}

.menu td:last-child {
    width: 60%;
}

.menu th {
    background-color: inherit;
}

.nav-panel {
    background-color: var(--bg-color);
    font-size: small;
    padding: 0.2em 1em;
}
/* END CLASSES */
