;;; test-data.el

;; Author:       Mats Lidell <matsl@gnu.org>
;;
;; Orig-Date:    24-Apr-25 at 22:20:39
;; Last-Mod:     24-Apr-25 at 22:22:16 by Mats Lidell
;;
;; SPDX-License-Identifier: GPL-3.0-or-later
;;
;; Copyright (C) 2025  Free Software Foundation, Inc.
;; See the "HY-COPY" file for license information.
;;
;; This file is part of GNU Hyperbole.

;;; Commentary:

;;; Code:

(defun test-func ()
  "Test function."
  nil)
